<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_AR" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>¡Hay vida más allá del navegador!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licencia para: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo lleva tiempo valioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor, &lt;a href=&apos;%1&apos;&gt;done&lt;/a&gt; para apoyar el desarrollo continuo de %2.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traduce %1 a tu idioma natal usando %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Iconos diseñados por %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publicado bajo la &lt;a href=&apos;%1&apos;&gt;Licencia Pública General de GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Introduzca los detalles de su licencia</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Correo electrónico:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Código:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Por favor autorice %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta prueba ha vencido.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>La versión completa le permite ver videos sin interrupciones.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Sin una licencia, la aplicación caducará en %1 días.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Al comprar la versión completa, también apoyas el duro trabajo que he puesto creado %1</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar Prueba</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Introducir licencia</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Comprar licencia</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Por %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Todos los videos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videos no vistos</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Última vez actualizado</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Último añadido</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Último visto</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Más visto</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Sortear por</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marcar todos como vistos</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Show actualizado</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>No tiene suscripciones. Haga click en el ícono de la estrella para suscribirse a un canal</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Todos los videos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Videos no vistos</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marcar como Visto</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Cancelar suscripción</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>No hay actualizaciones a sus suscripciones en este momento</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Justo Ahora</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 visitas</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/sec</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/sec</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restante(s)</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 descargado en %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descarga finalizada</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Cambiar destino...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Elegir el destino de la descarga</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Destino de la descarga cambiado.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Las descargas en curso van a seguir bajándose al destino anterior.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Bajando al: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>El archivo ejecutable ha sido corrompido, quizás por un virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 no ejecutará. Intenta instalar nuevamente.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Detener luego de la pista actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Pista siguiente</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista previa</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Subir volumen</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Bajar volumen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Mudo</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Avanzar rápido</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Retroceder rápido</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Encuentra vídeos por canales o por palabras clave</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Navega en los vídeos por categoría</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Suscripciones</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Mis suscripciones</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Personalizar</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener la reproducción y volver a la vista de búsqueda</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Volver a la pista previa</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Saltar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar al siguiente video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Continuar reproducción</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Modo Compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Esconder la lista de reproducción y la barra de herramientas</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Abrir la página de &amp;YouTube </translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir al video en YouTube y pausar la reproducción</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copiar el enlace de &amp;YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar el enlace de YouTube del video actual al portapapeles</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copiar Video &amp;URL</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar la URL del stream del video al portapapeles</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Encontrar Video &amp;Partes</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Encuentra las otras partes del video con suerte en el orden correcto</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Borrar los videos seleccionados de la lista</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover hacia &amp;arriba</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover hacia arriba los videos seleccionados</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover hacia &amp;abajo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover hacia abajo los videos seleccionados</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Borrar las búsquedas recientes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Eliminar el historial de búsqueda. No se puede deshacer.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adiós</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Sitio web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 en la Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Hacer una &amp;donación</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor apoya el desarrollo continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información sobre %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar volumen</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Iniciar Reproducción Manualmente</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Empezar a reproducir videos manualmente</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Descargas</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Mostrar detalles sobre la descarga de videos</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Bajar video</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Bajar el video actual</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Tomar &amp;Captura de pantalla</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Suscribirse al canal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Compartí el vídeo actual usando %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Correo</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correo</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Siempre Visible</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Finalizar Después de este Video</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Reportar un inconveniente</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Refinar Búsqueda</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Más...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Vídeos relacionados</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Mirar vídeos relacionados al vídeo actual</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Abrir en &amp;Navegador...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Modo restringido</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Ocultar videos que puedan tener contenido inapropiado</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>¿Amas %1? ¡Califícalo!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Comprar %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Programa</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Reproducción</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Compartir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Con %1 para subir el volumen, con %2 para bajarlo</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Selecciona la localidad de tu contenido</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Seguro que quieres salir de %1 con una descarga en progreso?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Si cierras %1 ahora, la descarga se va a cancelar.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Cerrar y cancelar descarga</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Esperar a que termine la descarga</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>Cargando...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Salir de &amp;Pantalla Completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volumen silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volumen activo</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Definición máxima de video ajustada en %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Tu privacidad ahora está segura</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Descarga completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 versión %2 está ahora disponible</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recordármelo después</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Ahora puedes pegar el enlace de YouTube en otra aplicación</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Ahora podés pegar la URL del stream en otra aplicación</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>El enlace va a ser válido sólo por un tiempo limitado.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Descargando %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>parte</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episodio</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Enviado desde %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Cancelar suscripción a %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Suscribirse a %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Desubscripto de %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Subscripto a %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Está disponible una nueva versión de %1.</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 está disponible ahora. Ud. tiene %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>¿Quiere descargarla ahora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Omitir esta versión</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Recordarme después</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar actualización</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 of %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Falló</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completado</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Detenido</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Detener descarga</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Mostrar en %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Abrir carpeta relacionada</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Reiniciar descarga</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>No hay videos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>No hay más vídeos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Sortear por</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevancia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Contador de Visitas</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Calificación</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 Días</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 Días</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Cortos</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medianos</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Largos</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Menores que 4 minutos</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>Entre 4 y 20 minutos</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Mayores a 20 minutos</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Alta Definición</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p o mayor</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Finalizado</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>para empezar a ver videos.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>una palabra clave</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Escribir</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Búsquedas recientes</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canales recientes</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Conseguir la versión completa</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Avanzar a %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Retroceder a %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Refinar Búsqueda</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Quiso decir: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Cambiar destino...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Captura de pantalla guardada en %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>La ubicación de la captura de pantalla ha sido cambiada.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Más populares</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descargando actualización…</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Descargando %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Bélgica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Canada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>República Checa</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egipto</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francia</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Alemania</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grecia</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungría</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japón</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordan</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malasia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>México</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marruecos</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Países Bajos</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nueva Zelanda</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Perú</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipinas</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polonia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sud Africa</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Sud Corea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>España</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suecia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Túnez</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turquía</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emiratos Arabes Unidos</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Reino Unido</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Todo el mundo</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>No puedo obtener el stream de video de %1</translation>
    </message>
</context>
</TS>